#ifndef _DOTYK_TLAC
#define _DOTYK_TLAC

/*

PTA0 - vystup pulsu komunikace s druhym modulem
        sirska impulsu     servo splachovani       vetrak
        ==================================================
           1.00 ms            dolni poloha         vypnuty            
           1.33 ms            horni poloha         vypnuty
           1.66 ms            dolni poloha         zapnuty
           2.00 ms            horni poloha         zapnuty
PTA1 - vystup - LED potvrzeni stisku tlacitka splachovani
PTA2 - vstup - dotykovy senzor splachovani
PTA3 - vystup - LED potvrzeni stisku tlacitka vetraku
PTA4 - vstup - dotykovy senzor vetraku
PTA5 - nepouzito
----------------------------------------------------------
PTB0 - vystup - LED podsviceni tlacitka splachovani
PTB1 - vystup - LED podsviceni tlacitka vetraku
PTB2 - nepouzito
PTB3 - nepouzito
PTB4 - nepouzito
PTB5 - nepouzito
PTB6 - nepouzito
PTB7 - nepouzito

*/

#define CLOCK_20MS_TICK_COUNTER_LIMIT  2     // 1 tiky do 40ms timer ticku

// stavovy registr 1
#define S1M_PWM_CHANNEL              0x01    // kanal PWM, do ktereho se psalo naposled
// bit 1,2 - 0 = splachovani vypnuto, 1 = splachovani zapnuto na prvi polohu, 2 = splachovani zapnuto na druhou polohu
#define S1M_SPLACHOVANI_ZAPNUTO_B1   0x02
#define S1M_SPLACHOVANI_ZAPNUTO_B2   0x04
#define S1M_VETRAK_ZAPNUT            0x08    // 1 = vetraku zapnut, 0 = vetrak vypnut
#define S1M_20ms_TIMER_TICK          0x10    // 20ms timer tick signalizovan
#define S1M_CASOVAC_VETRAKU_VYPNUT   0x20    // 1 - casovac vetraku potlacen, vetrak bude zapnut trvale
#define S1M_MOD_NASTAVENI            0x40    // 1 - nastavuje se splachovani (sec), 0 - nastavuje se vetrak (min)
#define S1M_NASTAVENI_JEDNOTEK       0x80    // 0 - nastavuji se desitky, 1 - nastavuji se jednotky

// stavovy registr 2
#define S2M_NASTAVOVANA_HODNOTA_SE_ZMENILA   0x01     // signalizace stavu zmeny nastavovane hodnoty
#define S2M_SIGNALIZOVANI_JEDNOTEK           0x02     // 0 - prvni cislice (desitky), blika se LED potvrzeni vetraku
                                                      // 1 - druha cislice (jednotky), blika se LED potvrzeni splachovani
#define S2M_PRILIS_KRATKA_DOBA_STISKU_SPLACHOVANI  0x04     // signalizace prilis kratke doby stisku splachovani


// minimalni doba, po kterou musi byt sepnute tlacitko, aby se zacalo vyhodnocovat
#define MIN_DOBA_SEPNUTI_TLACITKA_KRATCE              2       // x 20ms
#define MIN_DOBA_SEPNUTI_TLACITKA_VETRAKU_DLOUZE      250     // x 20ms
#define MIN_DOBA_SEPNUTI_TLACITKA_SPLACHOVANI_DLOUZE  20      // x 20ms
#define MIN_DOBA_SPLACHOVANI                          75      // x 20ms
#define MIN_DOBA_SEPNUTI_TLACITKA_PRO_NASTAVENI       500     // x 20ms

// masky pro ovladaci tlacitka
#define PORT_TLACITKA         PTA
#define TLACITKO_SPLACHOVANI  PTA_PTA2_MASK
#define TLACITKO_VETRAK       PTA_PTA4_MASK

#define PORT_LED_PODSVICENI               PTB
#define PORT_LED_POTVRZENI                PTA

#define LED_PODSVICENI_SPLACHOVANI        PTB_PTB0_MASK
#define LED_PODSVICENI_VETRAK             PTB_PTB1_MASK
#define LED_POTVRZENI_SPLACHOVANI         PTA_PTA1_MASK
#define LED_POTVRZENI_VETRAK              PTA_PTA3_MASK

#define TLACITKO_STISKNUTO( tlacitko )  ( !( PORT_TLACITKA & tlacitko ) )

// identifikace stavu stopek
#define STOPKY_VYPNUTO     0xFF
#define STOPKY_START       0xFE
#define STOPKY_SIGNAL      0xFD
#define POCET_TICKU_DO_SEKUNDY      50    // x 20ms
#define POCET_TICKU_DO_PUL_SEKUNDY  25    // x 20ms

// masky pro g_TLACITKA_STAV stavove priznaky
#define STISK_SPLACHOVANI_KRATCE_DETEKOVAN   0x01
#define STISK_SPLACHOVANI_DLOUZE_DETEKOVAN   0x02
#define STISK_VETRAK_KRATCE_DETEKOVAN        0x04
#define STISK_VETRAK_DLOUZE_DETEKOVAN        0x08
#define STISK_SPLACHOVANI_KRATCE_ZPRACOVAN   0x10
#define STISK_SPLACHOVANI_DLOUZE_ZPRACOVAN   0x20
#define STISK_VETRAK_KRATCE_ZPRACOVAN        0x40
#define STISK_VETRAK_DLOUZE_ZPRACOVAN        0x80
#define STISK_VSECH_KRATCE_A_DLOUZE_ZPRACOVAN  0xF0


#endif