#include "flash_variables.h"
#include "string.h"
#include "derivative.h" /* include peripheral declarations */

/* ROM Resident Routines Pointer Definitions */
//#define PRGRNGE #$2809    /* Program a range of FLASH locations */ 
//#define ERARNGE #$2806    /* Erase a page or a whole array of FLASH */ 
//#define RDVRRNG "0x2803"    /* Reads/Verifies a range of locations in FLASH */
//#define GETBYTE "0x2800"    /* Gets a byte of data from comm port */
//#define DELNUS  "0X280C"    /* Generate a delay */

/* RAM Data Block */
unsigned char CTRLBYT @0x0088;   /* Select between mass/page erase */
unsigned char CPUSPD  @0x0089;   /* CPU value equals 4x Bus speed */
unsigned int  LADDR   @0x008A;   /* Last address of FLASH to manipulate */
unsigned char DATA[ sizeof( FLASH_VARIABLES ) ] @0x008C;   /* Data to program into FLASH */

#define FADDR_VALUE 	0xEE00      /* adresa zacatku flash variables oblasti */

const unsigned char FLBPR_INIT @0x0000FFBE = 0xBC; /* Initialize Flash Block Protection */
/* start of address of protected range
0x00 - 0xB8    - entire flash is protected
0xB9           - protected from  0xEE40
0xBA           -                 0xEE80
0xBB           -                 0xEEC0
0xBC           -                 0xEF00
...
0xDE           -                 0xF780
0xDF           -                 0xF7C0
0xFE           -                 0xFF80      FLBPR, OSCTRIM and vectors are protected
0xFF           - entire flash is protected */                

void volatile StoreFLASHVariableEx( const unsigned char nDataOffset, 
											   const short data )
{
   /* RAM DATA Initialization */
   CTRLBYT = 0;      		   /* Page erase (clear bit-6) */
   CPUSPD = 13;      		   /* 3.2MHz * 4 = 12.8 = 13 (using internal OSC) */
   LADDR = FADDR_VALUE + sizeof( FLASH_VARIABLES ) - 1;   /* Last address in FLASH to program */

   /* DATA Buffer Initialization */
   (void)memcpy( DATA, &g_flashVariables, sizeof( FLASH_VARIABLES ) );  // current values
   (void)memcpy( DATA + nDataOffset, &data, 2 );	 // new value

	#asm
	    
	SEI
	
	LDHX #$EE00     		; Load to H:X address in FLASH range to be erased 
   JSR  $2806 				; Call ERARNGE ROM Subroutine 

   LDHX #$EE00 			; Load address of RAM Data Block to H:X 
   JSR  $2809        	; Call PRGRNGE ROM Subroutine 

   CLI
   
	#endasm
}

void volatile StoreFLASHVariable( const unsigned char nDataOffset, 
											 const unsigned char nData )
{
   /* RAM DATA Initialization */
   CTRLBYT = 0;      		   /* Page erase (clear bit-6) */
   CPUSPD = 13;      		   /* 3.2MHz * 4 = 12.8 = 13 (using internal OSC) */
   LADDR = FADDR_VALUE + sizeof( FLASH_VARIABLES ) - 1;   /* Last address in FLASH to program */

   /* DATA Buffer Initialization */
   (void)memcpy( DATA, &g_flashVariables, sizeof( FLASH_VARIABLES ) );  // current values
   (void)memcpy( DATA + nDataOffset, &nData, 1 );	 // new value

	#asm

   SEI
   	    
	LDHX #$EE00     		; Load to H:X address in FLASH range to be erased 
   JSR  $2806 				; Call ERARNGE ROM Subroutine 

   LDHX #$EE00 			; Load address of RAM Data Block to H:X 
   JSR  $2809        	; Call PRGRNGE ROM Subroutine 
   
   CLI

	#endasm
}
