#include <hidef.h> /* for EnableInterrupts macro */
#include "derivative.h" /* include peripheral declarations */

#include "DotykTlac.h"
#include "Flash_Variables.h"

static const byte g_bOSC_TRIM_VALUE @0xFFC0 = 0x60;      // FFC0=71		FFC1=68
byte g_ucSTATUS_1;
static byte g_ucSTATUS_2;                      
static word g_wLastPWMValue;
static byte g_ucNastavovanaHodnota_Desitky;           // aktualni nastavovana hodnota - prvni cislice
static byte g_ucNastavovanaHodnota_Jednotky;          // aktualni nastavovana hodnota - druha cislice

static word g_TLACITKO_SPLACHOVANI_DOBA_SEPNUTI;      // doba sepnuti tlacitka pro splachovani
static word g_TLACITKO_VETRAK_DOBA_SEPNUTI;           // doba sepnuti tlacitka vetrak

byte g_uc20msClockTicks;      // pro signalizaci 100ms intervalu na zaklade preruseni

// stopky pro vetrak
static word g_wStopkyVetrak_PocetSekund;           // doba zapnuti vetraku v sekundach
static byte g_ucStopkyVetrak_PocetTickuDoSekundy;  // stav stopek a pocet tiku casovace

// stopky pro splachovani
static word g_wStopkySplachovani_PocetPulSekund;        // doba pro prvni polohu splachovani v pulsekundach
static byte g_ucStopkySplachovani_PocetTickuDoSekundy;  // stav stopek a pocet tiku casovace

// stopky pro blikani LED splachovani
static byte g_ucStopkySplachovaniLED_PocetTickuCasovace;   // stav stopek a pocet tiku casovace

// stopky pro obecne pouziti
static word g_wStopky_PocetPulSekund;              // uplynula doba v sekundach
static byte g_ucStopky_PocetTickuDoSekundy;        // stav stopek a pocet tiku casovace 

// stav tlacitek - stisknuto kratce, dlouze + potvrzeni zpracovani stisku tlacitka
static byte g_ucTLACITKA_STAV;               // 2 tlacitka, kazde muze byt stisknuto kratce nebo podrzeno pro dlouhy stisk
                                             // bit 1: tlacitko "SPLACHOVANI" - kratky stisk
                                             // bit 2: tlacitko "SPLACHOVANI" - dlouhy stisk
                                             // bit 3: tlacitko "VETRAK" - kratky stisk
                                             // bit 4: tlacitko "VETRAK" - dlouhy stisk
                                             // potvrzeni zpracovani stisku tlacitek
                                             // bit 5: tlacitko "SPLACHOVANI" - kratky stisk zpracovan
                                             // bit 5: tlacitko "SPLACHOVANI" - dlouhy stisk zpracovan
                                             // bit 7: tlacitko "VETRAK" - kratky stisk zpracovan
                                             // bit 8: tlacitko "VETRAK" - dlouhy stisk zpracovan
                                             
static word g_wHodnota;       // word promenna pro obecne pouziti
static byte g_ucHodnota;      // byte promenna pro obecne pouziti


void MCU_init( void ); /* Device initialization function declaration */

static enum STAV_AUTOMATU
{
   STAV_V_KLIDU,
   STAV_VYBER_NASTAVOVANE_HODNOTY,
   STAV_NASTAVENI_HODNOTY, 
   STAV_UKONCENI_NASTAVENI,
   STAV_NASTAVENI_HODNOTY_INICIALIZACE,
   STAV_CEKANI_PRED_SIGNALIZACI_NASTAVENE_HODNOTY,
   STAV_CEKANI_PO_SIGNALIZACI_NASTAVENE_HODNOTY,
   STAV_SIGNALIZACE_NASTAVENE_HODNOTY
}
g_eStav;

void SetPWMOutput()
{
   // 3200 ~ 1.00 ms      vse vypnuto
   // 3840 ~ 1.20 ms      splachovani na prvni polohu
   // 4480 ~ 1.40 ms      splachovani na prvni polohu a vetrak zapnut
   // 5210 ~ 1.60 ms      splachovani na druhou polohu
   // 5760 ~ 1.80 ms      vetrak zapnut
   // 6400 ~ 2.00 ms      splachovani na druhou polohu a vetrak zapnut

   word wNewPWMValue;
   byte ucButtonState = g_ucSTATUS_1 & ( S1M_SPLACHOVANI_ZAPNUTO_B1 | S1M_SPLACHOVANI_ZAPNUTO_B2 | S1M_VETRAK_ZAPNUT );
   
   if( ucButtonState == 0x00 )
      wNewPWMValue = 3200;         // nic neni zapnuto
   else if( ucButtonState == S1M_SPLACHOVANI_ZAPNUTO_B1 )
      wNewPWMValue = 3840;         // splachovani zapnuto na prvni polohu
   else if( ucButtonState == ( S1M_SPLACHOVANI_ZAPNUTO_B1 | S1M_VETRAK_ZAPNUT ) )
      wNewPWMValue = 4480;         // splachovani zapnuto na prvni polohu a vetrak zapnut
   else if( ucButtonState == S1M_SPLACHOVANI_ZAPNUTO_B2 )
      wNewPWMValue = 5210;         // splachovani zapnuto na druhou polohu
   else if( ucButtonState == S1M_VETRAK_ZAPNUT )
      wNewPWMValue = 5760;         // vetrak zapnut
   else
      wNewPWMValue = 6400;         // splachovani na druhou polohu a vetrak zapnut
     
   if( g_wLastPWMValue == wNewPWMValue )
      return;  // nic se nezmenilo
      
   g_wLastPWMValue = wNewPWMValue;

   // buffered PWM - sirka pulzu je dana vzdy hodnotou registru, do ktereho se psalo naposled
	// synchronizovana zmena sirky pulsu se musi provest vzdy zapisem do nepouzivaneho registru
	if( !( g_ucSTATUS_1 & S1M_PWM_CHANNEL ) )
	{
		TCH1 = wNewPWMValue;
		g_ucSTATUS_1 |= S1M_PWM_CHANNEL;
	}
	else
	{
		TCH0 = wNewPWMValue;
		g_ucSTATUS_1 &= ~S1M_PWM_CHANNEL;
	}
}

void VypnutiStopek( void )
{ 
   g_ucStopky_PocetTickuDoSekundy = STOPKY_VYPNUTO;
   g_ucStopkySplachovani_PocetTickuDoSekundy = STOPKY_VYPNUTO;
   g_ucStopkyVetrak_PocetTickuDoSekundy = STOPKY_VYPNUTO;
   g_ucStopkySplachovaniLED_PocetTickuCasovace = STOPKY_VYPNUTO;
   g_uc20msClockTicks = 0;
}

void SpusteniStopek()
{
   g_ucStopky_PocetTickuDoSekundy = STOPKY_START;
   g_wStopky_PocetPulSekund = 0;
}

void SpusteniStopek_Vetrak()
{
   g_ucStopkyVetrak_PocetTickuDoSekundy = STOPKY_START;
   g_wStopkyVetrak_PocetSekund = 0;
}

void SpusteniStopek_Splachovani()
{
   g_ucStopkySplachovani_PocetTickuDoSekundy = STOPKY_START;
   g_wStopkySplachovani_PocetPulSekund = 0;
}

void SpusteniStopek_SplachovaniLED()
{
   g_ucStopkySplachovaniLED_PocetTickuCasovace = STOPKY_START;
}

// test stisku tlacitka
byte TlacitkoStisknuto( byte ucMaska, const byte bPotvrditStisk )
{
   byte bStav, ucMaskaPotvrzeni;

   // vyrobim masku pro potvrzeni
   ucMaskaPotvrzeni = ucMaska << 4;

   // test stisku tlacitek   
   bStav = ( ( ( g_ucTLACITKA_STAV & ucMaska ) == ucMaska ) 
             && ( ( g_ucTLACITKA_STAV & ucMaskaPotvrzeni ) == 0x00 ) ) ? 1 : 0;
            
   if( bStav
       && bPotvrditStisk )
   {     
      // potvrzeni stisku 
      g_ucTLACITKA_STAV |= ucMaskaPotvrzeni;

      if( ( ucMaskaPotvrzeni & ( STISK_SPLACHOVANI_DLOUZE_ZPRACOVAN | STISK_VETRAK_DLOUZE_ZPRACOVAN ) ) != 0 )
      {
         // je to dlouhy stisk => maska pro kratke stisky
         ucMaskaPotvrzeni = ucMaskaPotvrzeni >> 1;
         ucMaskaPotvrzeni &= 0xF0; 
            
         // potvrdim kratky stisk      
         g_ucTLACITKA_STAV |= ucMaskaPotvrzeni;      
      }
   }
                  
   return bStav;
}

void PotvrzeniStiskuTlacitka( const byte ucMaska )
{
   g_ucTLACITKA_STAV |= ucMaska;
}

void main( void ) 
{
   MCU_init();    /* call Device Initialization */

   /* include your code here */
   g_ucSTATUS_1 = 0x00;     
   g_ucSTATUS_2 = 0x00;
   g_wLastPWMValue = TCH0;
   g_ucTLACITKA_STAV = 0x00;
   g_TLACITKO_SPLACHOVANI_DOBA_SEPNUTI = 0xFFFF;
   g_TLACITKO_VETRAK_DOBA_SEPNUTI = 0xFFFF;
   g_eStav = STAV_V_KLIDU;
 
   // inicializace stopek
   VypnutiStopek();

   // inicializace LED
   PORT_LED_PODSVICENI |= ( LED_PODSVICENI_SPLACHOVANI | LED_PODSVICENI_VETRAK );
   PORT_LED_POTVRZENI &= ~( LED_POTVRZENI_SPLACHOVANI | LED_POTVRZENI_VETRAK );

   for( ; ; ) 
   {
      /* __RESET_WATCHDOG(); by default, COP is disabled with device init. When enabling, also reset the watchdog. */
      
      // uplynula doba timeru ?
      if( g_ucSTATUS_1 & S1M_20ms_TIMER_TICK )
      { // 100ms tick 
         g_ucSTATUS_1 &= ~S1M_20ms_TIMER_TICK; 

         // ===============================================================================
         // =============================== ZPRACOVANI TLACITEK ===========================
         
         // test stisku tlacitka "SPLACHOVANI"         
         if( TLACITKO_STISKNUTO( TLACITKO_SPLACHOVANI ) )
         { // je stisknuto tlacitko 

            if( g_ucSTATUS_2 & S2M_PRILIS_KRATKA_DOBA_STISKU_SPLACHOVANI )
            { // znovu stisknuto behem prilis kratke doby stisku tlacitka vetraku
               g_TLACITKO_SPLACHOVANI_DOBA_SEPNUTI = 0xFFFF;                          // reset casovace
               g_ucSTATUS_2 &= ~S2M_PRILIS_KRATKA_DOBA_STISKU_SPLACHOVANI;          // reset priznaku
            }
 
            if( g_TLACITKO_SPLACHOVANI_DOBA_SEPNUTI == 0xFFFF )
            { // zacatek stisku, vynuluju priznaky                            
               g_ucTLACITKA_STAV &= ~(   STISK_SPLACHOVANI_DLOUZE_DETEKOVAN | STISK_SPLACHOVANI_KRATCE_DETEKOVAN 
                                       | STISK_SPLACHOVANI_DLOUZE_ZPRACOVAN | STISK_SPLACHOVANI_KRATCE_ZPRACOVAN );
                                       
               g_TLACITKO_SPLACHOVANI_DOBA_SEPNUTI = 0x00;                                       
            }
            else if( g_TLACITKO_SPLACHOVANI_DOBA_SEPNUTI <= MIN_DOBA_SEPNUTI_TLACITKA_PRO_NASTAVENI )
            { // pocitam dobu stisku, dokud neni maximalni mozna => doba pro nastaveni
               g_TLACITKO_SPLACHOVANI_DOBA_SEPNUTI++;
            }
            
            if( !( g_ucTLACITKA_STAV & STISK_SPLACHOVANI_DLOUZE_DETEKOVAN ) )
            {                             
               if( g_TLACITKO_SPLACHOVANI_DOBA_SEPNUTI < MIN_DOBA_SEPNUTI_TLACITKA_KRATCE )
               { // jeste neuplynula minimalni doba sepnuti
               }
               else if( ( g_eStav == STAV_V_KLIDU 
                          && g_TLACITKO_SPLACHOVANI_DOBA_SEPNUTI < MIN_DOBA_SEPNUTI_TLACITKA_SPLACHOVANI_DLOUZE )
                        || ( g_eStav != STAV_V_KLIDU 
                             && g_TLACITKO_SPLACHOVANI_DOBA_SEPNUTI < MIN_DOBA_SEPNUTI_TLACITKA_VETRAKU_DLOUZE ) )
               {                  
                  // tlacitko je stisknuto "kratce"
                  g_ucTLACITKA_STAV |= STISK_SPLACHOVANI_KRATCE_DETEKOVAN;   
               }
               else
                  // tlacitko je stisknuto "dlouze"
                  g_ucTLACITKA_STAV |= STISK_SPLACHOVANI_DLOUZE_DETEKOVAN;   
            }
         }
         else
         { // tlacitko je uvolneno
            if( g_eStav == STAV_V_KLIDU )
            {
               if( ++g_TLACITKO_SPLACHOVANI_DOBA_SEPNUTI < MIN_DOBA_SPLACHOVANI )  // bylo stisknuto mene nez 50 * 20ms => jeste nemenim stav
                  g_ucSTATUS_2 |= S2M_PRILIS_KRATKA_DOBA_STISKU_SPLACHOVANI;
               else
               {
                  // reset pocitadla doby sepnuti
                  g_TLACITKO_SPLACHOVANI_DOBA_SEPNUTI = 0xFFFF;
                  
                  // reset priznaku
                  g_ucSTATUS_2 &= ~S2M_PRILIS_KRATKA_DOBA_STISKU_SPLACHOVANI;
               }
            }
            else
               // reset pocitadla doby sepnuti
               g_TLACITKO_SPLACHOVANI_DOBA_SEPNUTI = 0xFFFF;
            
            g_ucTLACITKA_STAV |= ( STISK_SPLACHOVANI_KRATCE_ZPRACOVAN | STISK_SPLACHOVANI_DLOUZE_ZPRACOVAN );
         }
         
         // test stisku tlacitka "VETRAK"         
         if( TLACITKO_STISKNUTO( TLACITKO_VETRAK ) )
         { // je stisknuto tlacitko          
            if( g_TLACITKO_VETRAK_DOBA_SEPNUTI == 0xFFFF )
            { // zacatek stisku, vynuluju priznaky                            
               g_ucTLACITKA_STAV &= ~(   STISK_VETRAK_DLOUZE_DETEKOVAN | STISK_VETRAK_KRATCE_DETEKOVAN 
                                       | STISK_VETRAK_DLOUZE_ZPRACOVAN | STISK_VETRAK_KRATCE_ZPRACOVAN );
                                       
               g_TLACITKO_VETRAK_DOBA_SEPNUTI = 0x00;                                       
            }
            else if( g_TLACITKO_VETRAK_DOBA_SEPNUTI <= MIN_DOBA_SEPNUTI_TLACITKA_PRO_NASTAVENI )
            { // pocitam dobu stisku, dokud neni maximalni mozna => doba pro nastaveni
               g_TLACITKO_VETRAK_DOBA_SEPNUTI++;
            }
      
            if( !( g_ucTLACITKA_STAV & STISK_VETRAK_DLOUZE_DETEKOVAN ) )
            {               
               // pocitam dobu sepnuti            
               if( g_TLACITKO_VETRAK_DOBA_SEPNUTI < MIN_DOBA_SEPNUTI_TLACITKA_KRATCE )
               { // jeste neuplynula minimalni doba sepnuti
               }
               else if( g_TLACITKO_VETRAK_DOBA_SEPNUTI < MIN_DOBA_SEPNUTI_TLACITKA_VETRAKU_DLOUZE )
               {
                  // tlacitko je stisknuto "kratce"
                  g_ucTLACITKA_STAV |= STISK_VETRAK_KRATCE_DETEKOVAN;   
               }
               else
                  // tlacitko je stisknuto "dlouze"
                  g_ucTLACITKA_STAV |= STISK_VETRAK_DLOUZE_DETEKOVAN;   
            }            
         }
         else
         { // tlacitko je uvolneno
            // reset pocitadla doby sepnuti
            g_TLACITKO_VETRAK_DOBA_SEPNUTI = 0xFFFF;                            
            
            g_ucTLACITKA_STAV |= ( STISK_VETRAK_KRATCE_ZPRACOVAN | STISK_VETRAK_DLOUZE_ZPRACOVAN );
         }

         // =============================== ZPRACOVANI TLACITEK ===========================
         // ===============================================================================


         // ===============================================================================
         // =============================== LED ============================
   
         if( g_eStav == STAV_V_KLIDU )
         {
            // LED splachovani
//            if( g_ucSTATUS_1 & ( S1M_SPLACHOVANI_ZAPNUTO_B1 | S1M_SPLACHOVANI_ZAPNUTO_B2 ) )
            if( g_ucSTATUS_1 & S1M_SPLACHOVANI_ZAPNUTO_B1 )
            { // je zapnuto splachovani na polohu 1
               PORT_LED_PODSVICENI &= ~LED_PODSVICENI_SPLACHOVANI;      // vypnu podsviceni
               PORT_LED_POTVRZENI |= LED_POTVRZENI_SPLACHOVANI;         // zapnu potvrzeni
            }
            else if( g_ucSTATUS_1 & S1M_SPLACHOVANI_ZAPNUTO_B2 )
            { // je zapnuto splachovani na polohu 2 - blikam rychle
               if( g_ucStopkySplachovaniLED_PocetTickuCasovace == STOPKY_VYPNUTO )
               {
                  SpusteniStopek_SplachovaniLED();
                  PORT_LED_PODSVICENI |= LED_PODSVICENI_SPLACHOVANI;       // zapnu podsviceni
                  PORT_LED_POTVRZENI &= ~LED_POTVRZENI_SPLACHOVANI;        // vypnu potvrzeni                                                  
               }
               else if( g_ucStopkySplachovaniLED_PocetTickuCasovace == 15 )    // je cas na bliknuti
               { // prehodim stav LED
                  if( PORT_LED_POTVRZENI & LED_POTVRZENI_SPLACHOVANI )
                  {
                     PORT_LED_PODSVICENI |= LED_PODSVICENI_SPLACHOVANI;       // zapnu podsviceni
                     PORT_LED_POTVRZENI &= ~LED_POTVRZENI_SPLACHOVANI;        // vypnu potvrzeni                  
                  }
                  else
                  {                     
                     PORT_LED_PODSVICENI &= ~LED_PODSVICENI_SPLACHOVANI;     // vypnu podsviceni
                     PORT_LED_POTVRZENI |= LED_POTVRZENI_SPLACHOVANI;        // zapnu potvrzeni                  
                  }

                  g_ucStopkySplachovaniLED_PocetTickuCasovace = STOPKY_START;    // spustim znovu stopky
               }
            }
            else
            { // je vypnuto splachovani
               PORT_LED_PODSVICENI |= LED_PODSVICENI_SPLACHOVANI;       // zapnu podsviceni
               PORT_LED_POTVRZENI &= ~LED_POTVRZENI_SPLACHOVANI;        // vypnu potvrzeni
            }

            // LED vetraku
            if( g_ucSTATUS_1 & S1M_VETRAK_ZAPNUT )
            { // je zapnuty vetrak
               if( g_ucStopkyVetrak_PocetTickuDoSekundy == STOPKY_SIGNAL )
               { // uplynula doba casovace               
                  if( g_ucSTATUS_1 & S1M_CASOVAC_VETRAKU_VYPNUT )
                  { // vetrak je zapnut natrvalo => blikam potvrzovaci LED
                     PORT_LED_POTVRZENI ^= LED_POTVRZENI_VETRAK;              // prepnu potvrzovaci LED
                        
                     if( PORT_LED_POTVRZENI & LED_POTVRZENI_VETRAK )
                        PORT_LED_PODSVICENI &= ~LED_PODSVICENI_VETRAK;        // vypnu podsviceni
                     else
                        PORT_LED_PODSVICENI |= LED_PODSVICENI_VETRAK;         // zapnu podsviceni
                     SpusteniStopek_Vetrak();                                 // spustim stopky
                  }
                  else
                  { // doba vetrani uplynula => vypnu vetrak
                     g_ucStopkyVetrak_PocetTickuDoSekundy = STOPKY_VYPNUTO;   // zastavim stopky
                     PORT_LED_POTVRZENI &= ~LED_POTVRZENI_VETRAK;              // vypnu potvrzovaci LED    
                     PORT_LED_PODSVICENI |= LED_PODSVICENI_VETRAK;             // zapnu podsviceni
                     g_ucSTATUS_1 &= ~S1M_VETRAK_ZAPNUT;                      // vypnu vetrak 
                  }
               }
               else
               { // casovac jeste bezi
                  if( ( g_ucSTATUS_1 & S1M_CASOVAC_VETRAKU_VYPNUT ) == 0 )  // neni vypnut casovac vetraku
                  {
                     PORT_LED_PODSVICENI &= ~LED_PODSVICENI_VETRAK;        // vypnu podsviceni
                     PORT_LED_POTVRZENI |= LED_POTVRZENI_VETRAK;           // zapnu potvrzovaci LED                
                  }
               }
            }
            else
            { // vetrak je vypnuty
               PORT_LED_PODSVICENI |= LED_PODSVICENI_VETRAK;            // zapnu podsviceni
               PORT_LED_POTVRZENI &= ~LED_POTVRZENI_VETRAK;             // vypnu potvrzovaci LED
            }
         } // if( g_eStav == STAV_V_KLIDU )
         // =============================== LED ============================
         // ===============================================================================         
         
         // ===============================================================================
         // ========================= stopky ==============================================
         if( g_ucStopkyVetrak_PocetTickuDoSekundy != STOPKY_VYPNUTO 
             && g_ucStopkyVetrak_PocetTickuDoSekundy != STOPKY_SIGNAL )
         { // stopky pro vetrak jsou v chodu
         
            if( g_ucStopkyVetrak_PocetTickuDoSekundy == STOPKY_START )
            { // spusteni stopek
               g_ucStopkyVetrak_PocetTickuDoSekundy = 0;
               g_wStopkyVetrak_PocetSekund = 0;
            }
            else 
            {
               g_ucHodnota = ( g_ucSTATUS_1 & S1M_CASOVAC_VETRAKU_VYPNUT ) ? POCET_TICKU_DO_PUL_SEKUNDY : POCET_TICKU_DO_SEKUNDY;
               if( ++g_ucStopkyVetrak_PocetTickuDoSekundy == g_ucHodnota ) 
               { // odtikala dalsi perioda
                  g_ucStopkyVetrak_PocetTickuDoSekundy = 0;
                     
                  if( ( g_ucSTATUS_1 & S1M_CASOVAC_VETRAKU_VYPNUT ) != 0   // blika se potvrzovaci LED
                      || ++g_wStopkyVetrak_PocetSekund == g_flashVariables.wDobaZapnutiVetraku )  // nebo uplynula doba casovace
                     g_ucStopkyVetrak_PocetTickuDoSekundy = STOPKY_SIGNAL;         // konec intervalu stopek
               }
            }
         }
                  
         if( g_ucStopky_PocetTickuDoSekundy != STOPKY_VYPNUTO
             && g_ucStopky_PocetTickuDoSekundy != STOPKY_SIGNAL )
         {            
            if( g_ucStopky_PocetTickuDoSekundy == STOPKY_START )
            { // spusteni stopek
               g_ucStopky_PocetTickuDoSekundy = 0;
               g_wStopky_PocetPulSekund = 0;     
            }
            else
            {
               if( ++g_ucStopky_PocetTickuDoSekundy == POCET_TICKU_DO_PUL_SEKUNDY )
               { // odtikala dalsi pulsekunda
                  g_ucStopky_PocetTickuDoSekundy = 0;
                  g_wStopky_PocetPulSekund++;
               }
            }
         }
         
         if( g_ucStopkySplachovaniLED_PocetTickuCasovace != STOPKY_VYPNUTO
             && g_ucStopkySplachovaniLED_PocetTickuCasovace != STOPKY_SIGNAL )
         {            
            if( g_ucStopkySplachovaniLED_PocetTickuCasovace == STOPKY_START )
            { // spusteni stopek
               g_ucStopkySplachovaniLED_PocetTickuCasovace = 0;
            }
            else
               g_ucStopkySplachovaniLED_PocetTickuCasovace++;
         }

         if( g_ucStopkySplachovani_PocetTickuDoSekundy != STOPKY_VYPNUTO
             && g_ucStopkySplachovani_PocetTickuDoSekundy != STOPKY_SIGNAL )
         {            
            if( g_ucStopkySplachovani_PocetTickuDoSekundy == STOPKY_START )
            { // spusteni stopek
               g_ucStopkySplachovani_PocetTickuDoSekundy = 0;
               g_wStopkySplachovani_PocetPulSekund = 0;     
            }
            else
            {
               if( ++g_ucStopkySplachovani_PocetTickuDoSekundy == POCET_TICKU_DO_PUL_SEKUNDY )
               { // odtikala dalsi pulsekunda
                  g_ucStopkySplachovani_PocetTickuDoSekundy = 0;               
                  g_wStopkySplachovani_PocetPulSekund++;

/*                  if( ( g_ucSTATUS_1 & ( S1M_SPLACHOVANI_ZAPNUTO_B2 | S1M_SPLACHOVANI_ZAPNUTO_B1 ) ) == S1M_SPLACHOVANI_ZAPNUTO_B1 )
                  { // splachovani je v poloze 1                  
                     if( g_wStopkySplachovani_PocetPulSekund >= 3 
                         && TLACITKO_STISKNUTO( TLACITKO_SPLACHOVANI ) )              
                     { // uplynula doba pro prvni polohu splachovace
                        // prehodim splachovani na polohu 2
                        g_ucSTATUS_1 &= ~S1M_SPLACHOVANI_ZAPNUTO_B1;
                        g_ucSTATUS_1 |= S1M_SPLACHOVANI_ZAPNUTO_B2;                        
                     }
                  }                  */
                  
                  if( TlacitkoStisknuto( STISK_SPLACHOVANI_DLOUZE_DETEKOVAN, 1 ) )
                  { // tlacitko splachovani stisknuto dlouze
                      // prehodim splachovani na polohu 2
                      g_ucSTATUS_1 &= ~S1M_SPLACHOVANI_ZAPNUTO_B1;
                      g_ucSTATUS_1 |= S1M_SPLACHOVANI_ZAPNUTO_B2;                        
                  }
                  
                  if( ( g_ucSTATUS_1 & ( S1M_SPLACHOVANI_ZAPNUTO_B2 | S1M_SPLACHOVANI_ZAPNUTO_B1 ) ) == S1M_SPLACHOVANI_ZAPNUTO_B2 )
                  { // splachovani je v poloze 2
                     if( ( g_wStopkySplachovani_PocetPulSekund / 2 ) >= g_flashVariables.wDobaZapnutiSplachovani       
                         && ( PORT_TLACITKA & TLACITKO_SPLACHOVANI ) != 0 )   // tlacitko splachovani uvolneno
                     { // konec splachovani
                        g_ucSTATUS_1 &= ~( S1M_SPLACHOVANI_ZAPNUTO_B1 | S1M_SPLACHOVANI_ZAPNUTO_B2 );  // vypnu splachovani
                        g_ucStopkySplachovani_PocetTickuDoSekundy = STOPKY_VYPNUTO;                // vypnu stopky                              
                        g_ucStopkySplachovaniLED_PocetTickuCasovace = STOPKY_VYPNUTO;                        
                     }
                  }                  
               }
            }
            
            // kontrola stavu tlacitka splachovani
            if( !TLACITKO_STISKNUTO( TLACITKO_SPLACHOVANI )
                //(  PORT_TLACITKA & TLACITKO_SPLACHOVANI ) != 0
                && ( g_ucSTATUS_1 & ( S1M_SPLACHOVANI_ZAPNUTO_B2 | S1M_SPLACHOVANI_ZAPNUTO_B1 ) ) == S1M_SPLACHOVANI_ZAPNUTO_B1 
                && !( g_ucSTATUS_2 & S2M_PRILIS_KRATKA_DOBA_STISKU_SPLACHOVANI ) )
            { // tlacitko splachovani uvolneno v poloze splachovani 1
                
               g_ucSTATUS_1 &= ~( S1M_SPLACHOVANI_ZAPNUTO_B1 | S1M_SPLACHOVANI_ZAPNUTO_B2 );  // vypnu splachovani
               g_ucStopkySplachovani_PocetTickuDoSekundy = STOPKY_VYPNUTO;                    // vypnu stopky                                 
               g_ucStopkySplachovaniLED_PocetTickuCasovace = STOPKY_VYPNUTO;
            }
         }
         // ========================= stopky ==============================================
         // ===============================================================================
      }
      
      switch( g_eStav )
      {
      case STAV_V_KLIDU:
         if( TlacitkoStisknuto( STISK_VETRAK_KRATCE_DETEKOVAN, 0 ) 
             //&& !TlacitkoStisknuto( STISK_SPLACHOVANI_KRATCE_DETEKOVAN, 0 ) )  
             && !TLACITKO_STISKNUTO( TLACITKO_SPLACHOVANI ) )
         { // stisk tlacitka pro vetrak kratce
            if( g_ucSTATUS_1 & S1M_VETRAK_ZAPNUT )    
            { // vetrak je zapnuty => vypnu
                g_ucSTATUS_1 &= ~(S1M_VETRAK_ZAPNUT | S1M_CASOVAC_VETRAKU_VYPNUT);     // vypnu vetrak
                g_ucStopkyVetrak_PocetTickuDoSekundy = STOPKY_VYPNUTO;                 // vypnu stopky
            }
            else                           
            { // vetrak je vypnuty => zapnu
               g_ucSTATUS_1 |= S1M_VETRAK_ZAPNUT;                             // zapnu vetrak
               g_ucSTATUS_1 &= ~S1M_CASOVAC_VETRAKU_VYPNUT;                   // vetrak je zapnut na omezenou dobu
               SpusteniStopek_Vetrak();                                       // spustim stopky
            }
                      
            PotvrzeniStiskuTlacitka( STISK_VETRAK_KRATCE_ZPRACOVAN );
         }
         else if( TlacitkoStisknuto( STISK_VETRAK_DLOUZE_DETEKOVAN, 0 )  
                  && !TLACITKO_STISKNUTO( TLACITKO_SPLACHOVANI ) )
         { // stisk tlacitka pro vetrak dlouze
            g_ucSTATUS_1 |= ( S1M_VETRAK_ZAPNUT | S1M_CASOVAC_VETRAKU_VYPNUT );   // zapnu vetrak bez omezeni doby
            SpusteniStopek_Vetrak();                                       // spustim stopky           
            
            PotvrzeniStiskuTlacitka( STISK_VETRAK_KRATCE_ZPRACOVAN 
                                     | STISK_VETRAK_DLOUZE_ZPRACOVAN );
         }     
         else if( TlacitkoStisknuto( STISK_SPLACHOVANI_KRATCE_DETEKOVAN, 0 ) 
                  && !TLACITKO_STISKNUTO( TLACITKO_VETRAK ) )
         { // stisk tlacitka pro splachovani kratce

            if( ( g_ucSTATUS_1 & ( S1M_SPLACHOVANI_ZAPNUTO_B1 | S1M_SPLACHOVANI_ZAPNUTO_B2 ) ) != 0 )
            { // splachovani je zapnuto
               // vypnu splachovani
               g_ucSTATUS_1 &= ~( S1M_SPLACHOVANI_ZAPNUTO_B1 | S1M_SPLACHOVANI_ZAPNUTO_B2 );
               
               // vypnu stopky
               g_ucStopkySplachovani_PocetTickuDoSekundy = STOPKY_VYPNUTO;
               g_ucStopkySplachovaniLED_PocetTickuCasovace = STOPKY_VYPNUTO;
            }
            else 
            {
               // zapnu splachovani na prvni polohu
               g_ucSTATUS_1 |= S1M_SPLACHOVANI_ZAPNUTO_B1;
               g_ucSTATUS_1 &= ~S1M_SPLACHOVANI_ZAPNUTO_B2;
            
               SpusteniStopek_Splachovani();                                       // spustim stopky
            }
            
            // potvrdim zpracovani tlacitek
            PotvrzeniStiskuTlacitka( STISK_SPLACHOVANI_KRATCE_ZPRACOVAN );
         }
         else if( TLACITKO_STISKNUTO( TLACITKO_SPLACHOVANI )
                  && TLACITKO_STISKNUTO( TLACITKO_VETRAK )
/*                  && ( g_ucTLACITKA_STAV & ( STISK_VETRAK_DLOUZE_DETEKOVAN | STISK_SPLACHOVANI_DLOUZE_DETEKOVAN ) ) 
                                             == ( STISK_VETRAK_DLOUZE_DETEKOVAN | STISK_SPLACHOVANI_DLOUZE_DETEKOVAN ) */
                  && g_TLACITKO_VETRAK_DOBA_SEPNUTI >= MIN_DOBA_SEPNUTI_TLACITKA_PRO_NASTAVENI
                  && g_TLACITKO_SPLACHOVANI_DOBA_SEPNUTI >= MIN_DOBA_SEPNUTI_TLACITKA_PRO_NASTAVENI )
         { // pozadavek na nastaveni
            g_eStav = STAV_VYBER_NASTAVOVANE_HODNOTY;    // zacinam nastavovat
            
            g_ucSTATUS_1 &= ~( S1M_VETRAK_ZAPNUT | S1M_CASOVAC_VETRAKU_VYPNUT 
                               | S1M_SPLACHOVANI_ZAPNUTO_B1 | S1M_SPLACHOVANI_ZAPNUTO_B2 );  // vypnu ovladani
            g_ucSTATUS_2 &= ~S2M_PRILIS_KRATKA_DOBA_STISKU_SPLACHOVANI;
            g_ucStopkyVetrak_PocetTickuDoSekundy = STOPKY_VYPNUTO;                           // vypnu stopky            
            g_ucStopkySplachovaniLED_PocetTickuCasovace = STOPKY_VYPNUTO;
            
            // nastavim LED
            PORT_LED_PODSVICENI &= ~( LED_PODSVICENI_SPLACHOVANI | LED_PODSVICENI_VETRAK );  // vypnu obe LED podsviceni
            PORT_LED_POTVRZENI &= ~LED_POTVRZENI_SPLACHOVANI;                                // vypnu LED potvrzeni splachovani
            PORT_LED_POTVRZENI |= LED_POTVRZENI_VETRAK;                                      // zapnu LED potvrzeni vetraku
            
            // zapnu stopky pro blikani LED
            VypnutiStopek();       // vypnuti vsech stopek
            SpusteniStopek();      // spustim stopky pro nastavovani

            // potvrdim zpracovani tlacitek
            PotvrzeniStiskuTlacitka( STISK_VSECH_KRATCE_A_DLOUZE_ZPRACOVAN );
         }
         
         asm( "wait" );
         break;
         
      case STAV_VYBER_NASTAVOVANE_HODNOTY:
         // vyber nastavovane hodnoty - doba splachovani v sec. nebo doba zapnuti vetraku v min.
         // blikam stridave potvrzovaci LED splachovani a vetraku, LED podsviceni je vypnuto
         if( g_ucStopky_PocetTickuDoSekundy != STOPKY_START )
         {
            if( ( g_wStopky_PocetPulSekund % 2 ) == 0 )
            { 
               PORT_LED_POTVRZENI &= ~LED_POTVRZENI_SPLACHOVANI;                 // vypnu LED potvrzeni splachovani
               PORT_LED_POTVRZENI |= LED_POTVRZENI_VETRAK;                       // zapnu LED potvrzeni vetraku
            }
            else
            {
               PORT_LED_POTVRZENI |= LED_POTVRZENI_SPLACHOVANI;               // zapnu LED potvrzeni splachovani
               PORT_LED_POTVRZENI &= ~LED_POTVRZENI_VETRAK;                   // vypnu LED potvrzeni vetraku            
            }
         }
         
         if( TlacitkoStisknuto( STISK_SPLACHOVANI_KRATCE_DETEKOVAN, 1 ) )
         { // bude se nastavovat splachovani v sekundach
            g_ucSTATUS_1 |= S1M_MOD_NASTAVENI;
            g_eStav = STAV_NASTAVENI_HODNOTY_INICIALIZACE;
            PotvrzeniStiskuTlacitka( STISK_VSECH_KRATCE_A_DLOUZE_ZPRACOVAN );
            break;            
         }

         if( TlacitkoStisknuto( STISK_VETRAK_KRATCE_DETEKOVAN, 1 ) )
         { // bude se nastavovat vetrak v minutach
            g_ucSTATUS_1 &= ~S1M_MOD_NASTAVENI;
            g_eStav = STAV_NASTAVENI_HODNOTY_INICIALIZACE;                   
            PotvrzeniStiskuTlacitka( STISK_VSECH_KRATCE_A_DLOUZE_ZPRACOVAN );     
            break;            
         }
         
         if( g_wStopky_PocetPulSekund >= 20 )      
         { // 10 sec. timeout na zvoleni funkce
            g_eStav = STAV_UKONCENI_NASTAVENI;      // koncim nastavovani
            g_wStopky_PocetPulSekund = STOPKY_VYPNUTO;
         }
         break;
                
      case STAV_NASTAVENI_HODNOTY_INICIALIZACE:
         //g_ucStopky_PocetTickuDoSekundy = STOPKY_START;     // spustim stopky
         SpusteniStopek();
         
         // cislice pro nastaveni
         g_ucSTATUS_1 &= ~S1M_NASTAVENI_JEDNOTEK;              // prvni cislice - desitky
         PORT_LED_POTVRZENI &= ~( LED_POTVRZENI_VETRAK | LED_POTVRZENI_SPLACHOVANI );
         PORT_LED_POTVRZENI |= LED_POTVRZENI_VETRAK;
         
         // pripravim nastavovanou hodnotu
         if( g_ucSTATUS_1 & S1M_MOD_NASTAVENI )
         { // nastavuje se splachovani
            g_wHodnota = g_flashVariables.wDobaZapnutiSplachovani;         // doba je v sekundach
         }
         else
         { // nastavuje se vetrak
            g_wHodnota = g_flashVariables.wDobaZapnutiVetraku;
            g_wHodnota /= 60;        // doba je v minutach !!!
         }                        
         g_ucNastavovanaHodnota_Desitky = (byte)( g_wHodnota / 10 );
         g_ucNastavovanaHodnota_Jednotky = g_wHodnota % 10;
         g_eStav = STAV_NASTAVENI_HODNOTY;
         break;
         
      case STAV_NASTAVENI_HODNOTY:
         // nastaveni dvoumistne hodnoty 
         // - kratkym stiskem tlacitka vetrak se voli cislice ( prvni, druha )
         // - kratkym stiskem tlacitka splachovani se pricita 1 k vybrane cislici
         // - dlouhym stiskem tlacitka vetrak se spusti indikace aktualni hodnoty, hodnota se zobrazuje blikanim na dane
         //   pozici ( vetrak - prvni pozice, splachovani - druha pozice ). Nula se indikuje bliknutim podsviceni.
                  
         // nastavim potvrzovaci LED
         if( g_ucStopky_PocetTickuDoSekundy != STOPKY_START )
         {
            // blikam LED pro prislusnou cislici
            g_ucHodnota = ( g_ucSTATUS_1 & S1M_NASTAVENI_JEDNOTEK ) ? LED_POTVRZENI_SPLACHOVANI : LED_POTVRZENI_VETRAK;
            if( ( g_wStopky_PocetPulSekund % 2 ) == 0 )
               PORT_LED_POTVRZENI |= g_ucHodnota;
            else
               PORT_LED_POTVRZENI &= ~g_ucHodnota;            
         }
         
         if( g_wStopky_PocetPulSekund >= 20 )      
         { // 10 sec. timeout pro neaktivitu
            g_eStav = STAV_UKONCENI_NASTAVENI;      // koncim nastavovani
            break;
         }
         
         if( ( ( g_ucSTATUS_2 & S2M_NASTAVOVANA_HODNOTA_SE_ZMENILA ) != 0
               && g_wStopky_PocetPulSekund >= 4 )       // po 2 sekundach se automaticky spusti indikace nastavene hodnoty
             || TlacitkoStisknuto( STISK_VETRAK_DLOUZE_DETEKOVAN, 1 ) )  // pozadavek na signalizaci ?
         {
            g_eStav = STAV_CEKANI_PRED_SIGNALIZACI_NASTAVENE_HODNOTY;    // prechazim do stavu signalizace cislice
            SpusteniStopek();                                            // vynuluju stopky
            g_ucSTATUS_2 &= ~S2M_SIGNALIZOVANI_JEDNOTEK;                 // bude se signalizovat prvni cislice - desitky            
            break;
         }
         
         if( TlacitkoStisknuto( STISK_VETRAK_KRATCE_DETEKOVAN, 1 ) )    // zmena na druhou nastavovanou cislice ?
         {         
            // prepnu na dalsi cislici
            g_ucSTATUS_1 ^= S1M_NASTAVENI_JEDNOTEK;
            
            // vynuluju stopky
            SpusteniStopek();
            
            // nastavim prislusnou potvrzovaci LED
            g_ucHodnota = ( g_ucSTATUS_1 & S1M_NASTAVENI_JEDNOTEK ) ? LED_POTVRZENI_SPLACHOVANI : LED_POTVRZENI_VETRAK;
            PORT_LED_POTVRZENI &= ~( LED_POTVRZENI_SPLACHOVANI | LED_POTVRZENI_VETRAK );
            PORT_LED_POTVRZENI |= g_ucHodnota;
            break;            
         }

         if( TlacitkoStisknuto( STISK_SPLACHOVANI_KRATCE_DETEKOVAN, 1 ) )   // zmena nastavovane cislice ?
         { 
            do
            {
               // pricteni 1 k nastavovane cislici
               if( g_ucSTATUS_1 & S1M_NASTAVENI_JEDNOTEK )
               { // druha cislice
                  g_ucNastavovanaHodnota_Jednotky++;
                  g_ucNastavovanaHodnota_Jednotky %= 10;
               }
               else
               { // prvni cislice
                  g_ucNastavovanaHodnota_Desitky++;
                  g_ucNastavovanaHodnota_Desitky %= 10;
               }

               // kontrola hodnoty
               g_wHodnota = g_ucNastavovanaHodnota_Desitky * 10;
               g_wHodnota += g_ucNastavovanaHodnota_Jednotky;
            } while( g_wHodnota == 0 );
                       
            // spustim stopky
            SpusteniStopek();
            
            // nastavim priznak pro signalizaci zmeny hodnoty
            g_ucSTATUS_2 |= S2M_NASTAVOVANA_HODNOTA_SE_ZMENILA;
            break;            
         }
         break;
         
      case STAV_CEKANI_PRED_SIGNALIZACI_NASTAVENE_HODNOTY:
         g_ucSTATUS_2 &= ~S2M_NASTAVOVANA_HODNOTA_SE_ZMENILA;           // schodim priznak zmeny cislice
         PORT_LED_POTVRZENI &= ~( LED_POTVRZENI_SPLACHOVANI | LED_POTVRZENI_VETRAK );  // zhasnu LED potvrzeni
         
         if( TlacitkoStisknuto( STISK_VETRAK_KRATCE_DETEKOVAN, 1 )
             || TlacitkoStisknuto( STISK_SPLACHOVANI_KRATCE_DETEKOVAN, 1 ) )
         { // preruseni signalizace nastavene hodnoty
            PotvrzeniStiskuTlacitka( STISK_VSECH_KRATCE_A_DLOUZE_ZPRACOVAN );
            SpusteniStopek();
            g_eStav = STAV_NASTAVENI_HODNOTY;                  // prechazim zpet na nastavovani honodnoty
            break;
         }
         
         if( g_wStopky_PocetPulSekund <= 2 )
         { // 1 sekundu cekam se zhasnutymi LED potvrzeni
            break;
         }
                  
         // prejdu na signalizaci hodnoty
         SpusteniStopek();
         g_eStav = STAV_SIGNALIZACE_NASTAVENE_HODNOTY;
         break;

      case STAV_SIGNALIZACE_NASTAVENE_HODNOTY:     
         if( TlacitkoStisknuto( STISK_VETRAK_KRATCE_DETEKOVAN, 1 )
             || TlacitkoStisknuto( STISK_SPLACHOVANI_KRATCE_DETEKOVAN, 1 ) )
         { // preruseni signalizace nastavene hodnoty
            PotvrzeniStiskuTlacitka( STISK_VSECH_KRATCE_A_DLOUZE_ZPRACOVAN );
            g_eStav = STAV_NASTAVENI_HODNOTY;                  // prechazim zpet na nastavovani honodnoty
            SpusteniStopek();
            PORT_LED_POTVRZENI &= ~( LED_POTVRZENI_SPLACHOVANI | LED_POTVRZENI_VETRAK );  // zhasnu LED potvrzeni
            break;
         }
                              
         if( ( g_ucSTATUS_2 & S2M_SIGNALIZOVANI_JEDNOTEK ) != 0 )
         { // jednotky
            g_wHodnota = g_ucNastavovanaHodnota_Jednotky;      // spocitam limitni hodnotu pro ticky
         }
         else
         { // desitky
            g_wHodnota = g_ucNastavovanaHodnota_Desitky;       // spocitam limitni hodnotu pro ticky
         }
                     
         if( g_wHodnota == 0 )
         { // nulova hodnota => zapnut LED na dobu 1.5 sec
            if( g_wStopky_PocetPulSekund < 4 )
            { // zapnu LED
               if( ( g_ucSTATUS_2 & S2M_SIGNALIZOVANI_JEDNOTEK ) != 0 )
                  PORT_LED_POTVRZENI |= LED_POTVRZENI_SPLACHOVANI;               
               else
                  PORT_LED_POTVRZENI |= LED_POTVRZENI_VETRAK;               
            }
            else
            { // konec signalizace
               goto KONEC_SIGNALIZACE;         
            }
         }
         else
         { // nenulova hodnota            
            g_wHodnota *= 2;        // pocita se o 0.5 sec.
            g_wHodnota -= 1;

            if( ( g_wStopky_PocetPulSekund % 2 ) == 0 )
            { // sudy tick => zapinam LED   
               if( g_wHodnota < g_wStopky_PocetPulSekund )
               { // konec signalizaci cislice 
KONEC_SIGNALIZACE:               
                  if( ( g_ucSTATUS_2 & S2M_SIGNALIZOVANI_JEDNOTEK ) == 0 )
                  { // prvni cislice - desitky
                     g_ucSTATUS_2 |= S2M_SIGNALIZOVANI_JEDNOTEK;                  // prepnu na jednoky
                     g_eStav = STAV_CEKANI_PRED_SIGNALIZACI_NASTAVENE_HODNOTY;    // pockam pred zobrazovanim cislice
                  }
                  else
                  { // druha cislice - jednotky
                     g_eStav = STAV_CEKANI_PO_SIGNALIZACI_NASTAVENE_HODNOTY;     // pockam pred prechodem zpet na nastavovani
                  }
           
                  SpusteniStopek();                                          // vynuluju stopky
                  PORT_LED_POTVRZENI &= ~( LED_POTVRZENI_SPLACHOVANI | LED_POTVRZENI_VETRAK );  // zhasnu LED potvrzeni               
               }
               else                                       
               {
                  // zapnu prislusnou potvrzovaci LED               
                  if( ( g_ucSTATUS_2 & S2M_SIGNALIZOVANI_JEDNOTEK ) != 0 )
                     PORT_LED_POTVRZENI |= LED_POTVRZENI_SPLACHOVANI;
                  else
                     PORT_LED_POTVRZENI |= LED_POTVRZENI_VETRAK;                  
               }
            }
            else
            { // lichy tick => vypinam LED
               PORT_LED_POTVRZENI &= ~( LED_POTVRZENI_SPLACHOVANI | LED_POTVRZENI_VETRAK );         
            }
         }                               
         break;
         
      case STAV_CEKANI_PO_SIGNALIZACI_NASTAVENE_HODNOTY:
         PORT_LED_POTVRZENI &= ~( LED_POTVRZENI_SPLACHOVANI | LED_POTVRZENI_VETRAK );  // zhasnu LED potvrzeni

         if( TlacitkoStisknuto( STISK_VETRAK_KRATCE_DETEKOVAN, 1 )
             || TlacitkoStisknuto( STISK_SPLACHOVANI_KRATCE_DETEKOVAN, 1 ) )
         { // preruseni signalizace nastavene hodnoty
            PotvrzeniStiskuTlacitka( STISK_VSECH_KRATCE_A_DLOUZE_ZPRACOVAN );
            SpusteniStopek();
            g_eStav = STAV_NASTAVENI_HODNOTY;                  // prechazim zpet na nastavovani honodnoty
            break;
         }
         
         if( g_wStopky_PocetPulSekund <= 2 )
         { // 1 sekundu cekam se zhasnutymi LED potvrzeni
            break;
         }
                  
         // prejdu na signalizaci hodnoty
         SpusteniStopek();
         g_eStav = STAV_NASTAVENI_HODNOTY;
         break;

      case STAV_UKONCENI_NASTAVENI:     
         g_wHodnota = g_ucNastavovanaHodnota_Desitky * 10;
         g_wHodnota += g_ucNastavovanaHodnota_Jednotky;
         
         if( ( g_ucSTATUS_1 & S1M_MOD_NASTAVENI ) == 0 )
         { // nastavuje se doba zapnuti vetraku v minutach
            g_wHodnota *= 60;
         }
         
         if( ( g_ucSTATUS_1 & S1M_MOD_NASTAVENI ) != 0 )   
         { // nastavuje se splachovani
            if( g_flashVariables.wDobaZapnutiSplachovani == g_wHodnota )
            { // nic se nezmenilo
               // reset programu
               _asm( "stop" );
               break;
            }
         }
         else
         { // nastavuje se vetrak
            
            if( g_flashVariables.wDobaZapnutiVetraku == g_wHodnota )
            { // nic se nezmenilo
               // reset programu
               _asm( "stop" );           
               break;
            }
         }
            
         TSC |= ( TSC_TSTOP | TSC_TRST );        // vypnu PWM
         PTA &= ~PTA_PTA0_MASK;                  // dam vystup na 0                  
                     
		   StoreFLASHVariableEx( 
		      ( g_ucSTATUS_1 & S1M_MOD_NASTAVENI ) == 0 ? DOBA_ZAPNUTI_VETRAKU_OFFSET : DOBA_ZAPNUTI_SPLACHOVANI_OFFSET, 
		      g_wHodnota );
                  
         // reset programu
         _asm( "stop" );           
         break;         
      };
      
      // aktualizuji vystupni signal
      SetPWMOutput();
            
   } /* loop forever */
  
   /* please make sure that you never leave main */
}
